@@ -39,7 +39,7 @@
 #'
 #' Capezza, C., Centofanti, F., Lepore, A., Palumbo, B. (2024)
 #' Robust Multivariate Functional Control Charts.
-#' \emph{Technometrics}, <doi:10.1080/00401706.2024.2327346>.
+#' \emph{Technometrics}, 66(4):531--547, <doi:10.1080/00401706.2024.2327346>.
 #'
 #' Centofanti, F., Colosimo, B.M., Grasso, M.L., Menafoglio, A., Palumbo, B.,
 #' Vantini, S. (2023)
@@ -75,6 +75,8 @@
 #' rpca <- rpca_mfd(mfdobj) # robust MFPCA
 #' # plot_pca_mfd(pca, harm = 1) # plot first eigenfunction, affected by outlier
 #' # plot_pca_mfd(rpca, harm = 1) # plot first eigenfunction in robust case
+#'
+#' @author C. Capezza, F. Centofanti
 rpca_mfd <- function(mfdobj,
                      center = "fusem", # TRUE, or fusem
                      scale = "funmad", # TRUE, FALSE, or funmad
@@ -486,7 +488,7 @@ rpca.fd <- function(fdobj,
 #'
 #' Capezza, C., Centofanti, F., Lepore, A., Palumbo, B. (2024)
 #' Robust Multivariate Functional Control Charts.
-#' \emph{Technometrics}, <doi:10.1080/00401706.2024.2327346>.
+#' \emph{Technometrics}, 66(4):531--547, <doi:10.1080/00401706.2024.2327346>.
 #'
 #' Leung, A., Yohai, V., and Zamar, R. (2017).
 #' Multivariate location and scatter matrix
@@ -501,6 +503,7 @@ rpca.fd <- function(fdobj,
 #' out <- functional_filter(mfdobj)
 #' }
 #'
+#' @author C. Capezza, F. Centofanti
 functional_filter <- function(mfdobj,
                               method_pca = "ROBPCA",
                               alpha = 0.95,
@@ -797,11 +800,11 @@ univ_fil_gse <- function(v, alpha, df) {
 #'
 #' Capezza, C., Centofanti, F., Lepore, A., Palumbo, B. (2024)
 #' Robust Multivariate Functional Control Charts.
-#' \emph{Technometrics}, <doi:10.1080/00401706.2024.2327346>.
+#' \emph{Technometrics}, 66(4):531--547, <doi:10.1080/00401706.2024.2327346>.
 #'
 #' Van Ginkel, J. R., Van der Ark, L. A., Sijtsma, K., and Vermunt, J. K.
 #' (2007). Two-way
-#' imputation: a bayesian method for estimating missing scores in tests
+#' imputation: a Bayesian method for estimating missing scores in tests
 #' and questionnaires, and an accurate approximation.
 #' \emph{Computational Statistics & Data Analysis}, 51(8):4013–-4027.
 #'
@@ -814,6 +817,7 @@ univ_fil_gse <- function(v, alpha, df) {
 #' mfdobj_imp <- RoMFDI(out$mfdobj)
 #' }
 #'
+#' @author C. Capezza, F. Centofanti
 RoMFDI <- function(mfdobj,
                    method_pca = "ROBPCA",
                    fev = 0.999,
@@ -973,7 +977,7 @@ RoMFDI <- function(mfdobj,
       x_new_com <- as.numeric(fd_new$coefs)
 
       x_new_com[mvar] <- x_new_com[mvar] +
-        mvtnorm::rmvnorm(1, mean = rep(0, length(x_new)), new_cov_err)
+        MASS::mvrnorm(1,  rep(0, length(x_new)), new_cov_err)
 
       coef_list[[inn]] <- matrix(x_new_com, nrow = nbasis, ncol = nvar)
 
@@ -1144,7 +1148,7 @@ RoMFDI <- function(mfdobj,
 #'
 #' Capezza, C., Centofanti, F., Lepore, A., Palumbo, B. (2024)
 #' Robust Multivariate Functional Control Charts.
-#' \emph{Technometrics}, <doi:10.1080/00401706.2024.2327346>.
+#' \emph{Technometrics}, 66(4):531--547, <doi:10.1080/00401706.2024.2327346>.
 #'
 #' @examples
 #' \dontrun{
@@ -1162,6 +1166,8 @@ RoMFDI <- function(mfdobj,
 #'                          mod_phase1 = mod_phase1)
 #' plot_control_charts(phase2)
 #' }
+#'
+#' @author C. Capezza, F. Centofanti
 RoMFCC_PhaseI <- function(mfdobj,
                           mfdobj_tuning = NULL,
                           functional_filter_par = list(filter = TRUE),
@@ -1532,7 +1538,7 @@ RoMFCC_PhaseI <- function(mfdobj,
 #' @references
 #' Capezza, C., Centofanti, F., Lepore, A., Palumbo, B. (2024)
 #' Robust Multivariate Functional Control Charts.
-#' \emph{Technometrics}, <doi:10.1080/00401706.2024.2327346>.
+#' \emph{Technometrics}, 66(4):531--547, <doi:10.1080/00401706.2024.2327346>.
 #'
 #' @examples
 #' \dontrun{
@@ -1550,6 +1556,8 @@ RoMFCC_PhaseI <- function(mfdobj,
 #'                          mod_phase1 = mod_phase1)
 #' plot_control_charts(phase2)
 #' }
+#'
+#' @author C. Capezza, F. Centofanti
 RoMFCC_PhaseII <- function(mfdobj_new,
                            mod_phase1) {
 
